Stan Math Library: stan/math/prim/scal/meta/partials_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

partials_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_PARTIALS_TYPE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_PARTIALS_TYPE_HPP
3
4 namespace stan {
5
6 template <typename T>
7 struct partials_type {
8 typedef T type;
9 };
10
11 }
12 #endif
13
stan::partials_type::type
T type
Definition: partials_type.hpp:8
stan
Definition: log_sum_exp.hpp:8
stan::partials_type
Definition: partials_type.hpp:7

[ Stan Home Page ] © 2011–2016, Stan Development Team.